.default-header {
    width: 100% !important;
    box-shadow: -21.213px 21.213px 30px 0px rgba(158, 158, 158, 0.3);
}

.menutop-wrap {
    background-color: $offwhite;
    .menu-top .list li {
        padding: 9px 15px;
        &:last-child {
            padding-right: 0;
        }
        text-transform:uppercase &:hover {
            a {
                color: #fff;
            }
            cursor:pointer;
        }
        a {
            font-weight: 600;
            color: #222;
            text-transform: uppercase;
            @media(max-width: 462px) {
                font-size:8px;
                padding: 5px 0px;
            }
        }
    }
    @media(max-width:992px) {
        display: none;
    }
}

.header-wrap {
    padding: 20px 0;
}

.sticky-wrapper {
    height: 34px !important;
}

@media(max-width: 992px) {
    .navbar-nav {
        height: auto;
        max-height: 400px;
        overflow-x: hidden;
    }
}

.default-header {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    z-index: 9;
}

.menu-bar {
    cursor: pointer;
    span {
        color: $black;
        font-size: 24px;
    }
}

.main-menu {
    background: #fff;
    @media (max-width: 991px) {
        height: 80px;
        line-height: 80px;
        padding-left: 24px;
    }
}

.main-menubar {
    display: none !important;
}

@include media-breakpoint-down(md) {
    .main-menubar {
        display: block !important;
    }
}

.menu-top {
    li {
        display: inline-block;
        @include transition();
        &:hover {
            background-color: $primary-color;
            a {
                color: $white !important;
            }
        }
    }
}

/*--------------------------------------------------------------
# Navigation Menu
--------------------------------------------------------------*/

/* Nav Menu Essentials */

.nav-menu,
.nav-menu * {
    margin: 0;
    padding: 0;
    list-style: none;
}

.nav-menu ul {
    position: absolute;
    display: none;
    top: 100%;
    right: 0;
    z-index: 99;
}

.nav-menu li {
    position: relative;
    white-space: nowrap;
}

.nav-menu>li {
    float: left;
}

.nav-menu li:hover>ul,
.nav-menu li.sfHover>ul {
    display: block;
}

.nav-menu ul ul {
    top: 0;
    right: 100%;
}

.nav-menu ul li {
    min-width: 180px;
}

/* Nav Menu Arrows */

.sf-arrows .sf-with-ul {
    padding-right: 30px;
}

.sf-arrows .sf-with-ul:after {
    content: "\f107";
    position: absolute;
    right: 15px;
    font-family: FontAwesome;
    font-style: normal;
    font-weight: normal;
}

.sf-arrows ul .sf-with-ul:after {
    content: "\f105";
}

/* Nav Meu Container */

@media (max-width: 768px) {
    #nav-menu-container {
        display: none;
    }
}

/* Nav Meu Styling */

.nav-menu {
    a {
        padding: 29px 8px;
        text-decoration: none;
        display: inline-block;
        color: $title-color;
        font-weight: 500;
        font-size: 12px;
        text-transform: uppercase;
        outline: none;
	}
	&:last-child {
		a {
			padding-right: 15px;
		}
	}
}

.nav-menu li:hover>a,
.nav-menu>.menu-active>a {
    color: $primary-color;
}

.nav-menu>li {
    margin-left: 20px;
}

.nav-menu ul {
    padding: 10px;
    box-shadow: 0px 6px 16px rgba(127, 137, 161, 0.25);
    background: #fff;
}

.nav-menu ul li {
    transition: 0.3s;
}

.nav-menu ul li a {
    padding: 5px 10px;
    color: #333;
    transition: 0.3s;
    display: block;
    font-size: 12px;
    text-transform: none;
}

.nav-menu ul li:hover>a {
    color: $primary-color;
}

.nav-menu ul ul {
    margin-right: 10px;
    margin-top: 0;
}

/* Mobile Nav Toggle */

#mobile-nav-toggle {
    position: fixed;
    right: 15px;
    z-index: 999;
    top: 28px;
    border: 0;
    background: none;
    font-size: 24px;
    display: none;
    transition: all 0.4s;
    outline: none;
    cursor: pointer;
    @media (max-width: 991px) {
        top: 28px;
    }
}

#mobile-nav-toggle i {
    color: $primary-color;
    font-weight: 900;
}

@media (max-width: 960px) {
    #mobile-nav-toggle {
        display: inline;
    }
    #nav-menu-container {
        display: none;
    }
}

/* Mobile Nav Styling */

#mobile-nav {
    position: fixed;
    top: 0;
    padding-top: 18px;
    bottom: 0;
    z-index: 998;
    background: rgba(0, 0, 0, 0.8);
    left: -260px;
    width: 260px;
    overflow-y: auto;
    transition: 0.4s;
}

#mobile-nav ul {
    padding: 0;
    margin: 0;
    list-style: none;
}

#mobile-nav ul li ul {
    display: none;
}

#mobile-nav ul li {
    position: relative;
}

#mobile-nav ul li a {
    color: #fff;
    font-size: 13px;
    text-transform: uppercase;
    overflow: hidden;
    padding: 10px 22px 10px 15px;
    position: relative;
    text-decoration: none;
    width: 100%;
    display: block;
    outline: none;
    font-weight: 700;
}

#mobile-nav ul li a:hover {
    color: #fff;
}

#mobile-nav ul li li {
    padding-left: 30px;
}

#mobile-nav ul .menu-has-children i {
    position: absolute;
    right: 0;
    z-index: 99;
    padding: 15px;
    cursor: pointer;
    color: #fff;
}

#mobile-nav ul .menu-has-children i.fa-chevron-up {
    color: $primary-color;
}

#mobile-nav ul .menu-has-children li a {
    text-transform: none;
}

#mobile-nav ul .menu-item-active {
    color: $primary-color;
}

#mobile-body-overly {
    width: 100%;
    height: 100%;
    z-index: 997;
    top: 0;
    left: 0;
    position: fixed;
    background: rgba(0, 0, 0, 0.7);
    display: none;
}

/* Mobile Nav body classes */

body.mobile-nav-active {
    overflow: hidden;
}

body.mobile-nav-active #mobile-nav {
    left: 0;
}

body.mobile-nav-active #mobile-nav-toggle {
    color: #fff;
}